# h1 标题

## h2 标题

### h3 标题

#### h4 标题

##### h5 标题

###### h6 标题

## 水平线

___

---

***

## 文本样式

**This is bold text**

__This is bold text__

*This is italic text*

_This is italic text_

~~Strikethrough~~

## 列表

无序

+ Create a list by starting a line with `+`, `-`, or `*`
+ Sub-lists are made by indenting 2 spaces:
  - Marker character change forces new list start:
    * Ac tristique libero volutpat at
    + Facilisis in pretium nisl aliquet
    - Nulla volutpat aliquam velit
+ Very easy!

有序

1. Lorem ipsum dolor sit amet
2. Consectetur adipiscing elit
3. Integer molestie lorem at massa

1. You can use sequential numbers...
2. ...or keep all the numbers as `1.`

Start numbering with offset:

57. foo
58. bar

## 代码

Inline `code`

Indented code

    // Some comments
    line 1 of code
    line 2 of code
    line 3 of code

Block code "fences"

```
Sample text here...
```

Syntax highlighting

```js
var foo = function (bar) {
  return bar++;
};

console.log(foo(5));
```

| a   | b   | c   |
| --- | --- | --- |
| 1   | 2   | 3   |

![001.jpg](https://s2.loli.net/2023/09/22/ypQfZoMTYz8gc4D.jpg)

[Planck 配列键盘使用心得 - 少数派 (sspai.com)](https://sspai.com/post/81740)


